===========================
Connexions Database Library
===========================

.. image:: https://travis-ci.org/Connexions/cnx-db.svg
   :target: https://travis-ci.org/Connexions/cnx-db

.. image:: https://img.shields.io/codecov/c/github/Connexions/cnx-db.svg
   :target: https://codecov.io/gh/Connexions/cnx-db

.. image:: https://badge.fury.io/py/cnx-db.svg
   :target: http://badge.fury.io/py/cnx-db

View the `documentation <http://cnx-db.readthedocs.io/en/latest/>`_
on the Read the Docs site.

License
-------

This software is subject to the provisions of the GNU Affero General
Public License Version 3.0 (AGPL). See license.txt for details.
Copyright (c) 2016 Rice University
